@@ -1,6 +1,4 @@
-# shadowstep/locator/__init__.py
-"""
-Locator converter module for converting between different locator formats.
+"""Locator converter module for converting between different locator formats.
 
 This module provides converters for:
 - UiSelector strings
